/*
 * SPDX-FileCopyrightText: (C) 2024 Red Hat, Inc. (www.redhat.com)
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#ifndef E_M365_COMP_EDITOR_EXTENSION_H
#define E_M365_COMP_EDITOR_EXTENSION_H

#include <glib-object.h>

G_BEGIN_DECLS

void	e_m365_comp_editor_extension_type_register	(GTypeModule *type_module);

G_END_DECLS

#endif /* E_M365_COMP_EDITOR_EXTENSION_H */
